#
# spec file for package osmo-sgsn
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %{nil}

%define with_iu 1
Name:           osmo-sgsn
Version:        1.8.0
Release:        bp156.2.10
Summary:        Osmocom's SGSN for 2G and 3G packet-switched mobile networks
License:        AGPL-3.0-or-later AND GPL-2.0-or-later
Group:          Productivity/Telephony/Servers
URL:            https://osmocom.org/projects/osmosgsn/wiki/OsmoSGSN
Source:         %{name}-%{version}.tar.xz
Patch1:         harden_osmo-gtphub.service.patch
Patch2:         harden_osmo-sgsn.service.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libcares)
BuildRequires:  pkgconfig(libcrypto) >= 0.9.5
BuildRequires:  pkgconfig(libgtp) >= 1.8.0
BuildRequires:  pkgconfig(libosmo-gsup-client) >= 1.4.0
BuildRequires:  pkgconfig(libosmo-netif) >= 1.1.0
BuildRequires:  pkgconfig(libosmoabis) >= 1.2.0
BuildRequires:  pkgconfig(libosmocore) >= 1.6.0
BuildRequires:  pkgconfig(libosmoctrl) >= 1.6.0
BuildRequires:  pkgconfig(libosmogb) >= 1.6.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.6.0
BuildRequires:  pkgconfig(libosmovty) >= 1.6.0
%{?systemd_requires}
%if %{with_iu}
BuildRequires:  pkgconfig(libasn1c)
BuildRequires:  pkgconfig(libosmo-ranap) >= 0.8.0
BuildRequires:  pkgconfig(libosmo-sigtran) >= 1.5.0
%endif

%description
OsmoSGSN is Osmocom's Serving GPRS Support Node for 2G and 3G
packet-switched mobile networks.

%package -n osmo-gtphub
Summary:        Osmocom GTP Hub: Proxy for GTP traffic between multiple SGSNs and GGSNs
Group:          Productivity/Telephony/Servers

%description -n osmo-gtphub
Osmocom GTP Hub: Proxy for GTP traffic between multiple SGSNs and GGSNs.

%package -n osmo-gbproxy
Summary:        Osmocom GPRS Gb Interface Proxy
Group:          Productivity/Telephony/Servers

%description -n osmo-gbproxy
The purpose of the Gb proxy is to aggregate the Gb links of multiple
BSS's and present them in one Gb link to the SGSN.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
echo "%{version}" >.tarball-version
autoreconf -fi
%configure \
%if %{with_iu}
  --enable-iu \
%endif
  --docdir=%{_docdir}/%{name} \
  --with-systemdsystemunitdir=%{_unitdir}
make %{?_smp_mflags}

%install
%make_install
install -d %{buildroot}/%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcosmo-gtphub
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcosmo-sgsn

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%preun -n osmo-gtphub
%service_del_preun osmo-gtphub.service

%postun -n osmo-gtphub
%service_del_postun osmo-gtphub.service

%pre -n osmo-gtphub
%service_add_pre osmo-gtphub.service

%post -n osmo-gtphub
%service_add_post osmo-gtphub.service

%check
make %{?_smp_mflags} check || (find . -name testsuite.log -exec cat {} +)

%files
%doc AUTHORS README
%dir %{_docdir}/%{name}/examples
%dir %{_docdir}/%{name}/examples/osmo-sgsn
%exclude %{_docdir}/%{name}/examples/osmo-gtphub
%{_docdir}/%{name}/examples/osmo-sgsn/osmo-sgsn-accept-all.cfg
%{_docdir}/%{name}/examples/osmo-sgsn/osmo-sgsn.cfg
%{_docdir}/%{name}/examples/osmo-sgsn/osmo-sgsn_custom-sccp.cfg
%{_bindir}/osmo-sgsn
%dir %{_sysconfdir}/osmocom
%config(noreplace) %{_sysconfdir}/osmocom/osmo-sgsn.cfg
%{_unitdir}/%{name}.service
%{_sbindir}/rcosmo-sgsn

%files -n osmo-gtphub
%dir %{_docdir}/%{name}/examples
%dir %{_docdir}/%{name}/examples/osmo-gtphub
%{_docdir}/%{name}/examples/osmo-gtphub/osmo-gtphub-1iface.cfg
%{_docdir}/%{name}/examples/osmo-gtphub/osmo-gtphub.cfg
%{_bindir}/osmo-gtphub
%dir %{_sysconfdir}/osmocom
%config(noreplace) %{_sysconfdir}/osmocom/osmo-gtphub.cfg
%{_unitdir}/osmo-gtphub.service
%{_sbindir}/rcosmo-gtphub

%changelog
* Fri Nov 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.8.0
  * https://git.osmocom.org/osmo-sgsn/plain/debian/changelog?h=1.8.0
- Drop patch:
  * harden_osmo-gbproxy.service.patch
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_osmo-gbproxy.service.patch
  * harden_osmo-gtphub.service.patch
  * harden_osmo-sgsn.service.patch
* Sat Sep 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.6.2
  * gtphub: rename sgsn's oww osmo_sockaddr into sgsn_sockaddr
* Sat Aug  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.6.1
  * gtphub_test: Fix compilation with gcc-10
- Remove not longer needed patch:
  * 0001-gtphub_test-Fix-compilation-with-gcc-10.patch
* Thu Jun 11 2020 Martin Hauke <mardnh@gmx.de>
- Add patch to fix gcc10 compilation errors (boo#1160244)
  * 0001-gtphub_test-Fix-compilation-with-gcc-10.patch
* Sat Jan  4 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.6.0
  * Improve logging in gprs_llc.c code
  * sgsn: Gb: implementing PS Paging when MS is MM_STANDBY
  * sgsn_libgtp: refactor ps paging into gprs_gb
  * ranap: add non-spec X1001
  * Iu: implement a user inactivity timer
  * Implement GMM State using osmocom FSM
  * Introduce FSM mm_state_iu_fsm, mm_state_gb_fsm
  * gprs_gmm: only update gb/iu cell information when Iu/Gb present
  * vty: Introduce cs7-instance-iu
  * gprs/gprs_gmm: implement T3314. Timeout to reset MM state
    READY->STANDBY
- Update to new upstream release 1.5.0
  * sgsn: Have authentication required on by default
  * osmo-sgsn: add VTY parameter to toggle authentication
  * sgsn_libgtp: Use new per-GSN libgtp API instead of deprecated
    API
  * Fix IMSI padding in imsi-acl
  * Improve 'show subscriber cache' vty command
* Sat Jul 27 2019 Martin Hauke <mardnh@gmx.de>
- Disable LTO for now since it breaks compilation of the tests
  See: https://osmocom.org/issues/4116
* Wed Jan 30 2019 mardnh@gmx.de
- Update to new upstream release 1.4.0
  * gprs_gmm: introduce a GMM Attach Request FSM
  * sgsn_ggsn_ctx_drop_pdp: protect against nullpointer when MM is gone
  * gprs_gmm: dont answer unknown IMSI/TMSI on Service Requests NET_FAIL
  * gprs_gmm: Fix missing Security Command for 3G when attaching
  * sgsn_libgtp: fix a potential memleak when the GGSN is not reachable
  * gb_proxy: Add ctrl interface and nsvc-state, gbproxy-state commands
  * osmo-sgsn: ping GGSN periodically and check for restart counter
  * Disarm T3395 when dettaching mmctx from pdpctx
  * sgsn: cdr: Fix uninitialized string access if ggsn is detached
  * gbproxy: Add VTY parameter: link stored-msgs-max-length
  * gbproxy: Add new VTY-managed timer: link-list clean-stale-timer
  * Remove local libgsupclient; Use libosmo-gsup-client from osmo-hlr
  * Full changelogs since 1.2.0:
    http://git.osmocom.org/osmo-sgsn/plain/debian/changelog?h=1.4.0
    http://git.osmocom.org/osmo-sgsn/plain/debian/changelog?h=1.3.0
- Remove patches:
  * osmo-sgsn-fix-includes.patch
* Fri Dec 29 2017 mardnh@gmx.de
- Add patch:
  * osmo-sgsn-fix-includes.patch
* Fri Dec 29 2017 jengelh@inai.de
- %%service_* already takes care of restart/removal
  Compact %%service_* since it incurs extra code.
  Resolve package-name-repeated-in-summary.
* Thu Dec 28 2017 mardnh@gmx.de
- Initial package, version 1.2.0
